#ifndef __Article_h__
#define __Article_h__

#include <cadadata/CADAData.h>
#include <cadadata/Base.h>
#include <cadadata/Exception.h>
#include <cadadata/Dealer.h>
#include <cadadata/Gallery.h>

#include <librfcdal/DalDatabase.h>
//#include <librfc/XMLNode.hpp>

#include <string>
#include <map>

namespace CADAData
{
//	const int nNotAnArticleRow = 5001;
//	const int nNotAnArticleNode = 5002;
//	const int nInvalidUnit = 5003;

	class CADAData_Export Article //: public Base
	{
		public:
			typedef enum { unit_mm, unit_cm, unit_inch } Unit;

		private:
			int _nArticleId;
			const CADAData::Dealer* _pdealer;
			const CADAData::Gallery* _pgallery;
			std::string _strShortDesc;
			std::string _strDescription;
			std::string _strFaults;
			std::string _strCirca;
			std::string _strNote;
			std::string _strImage0;
			std::string _strImage1;
			std::string _strImageS;
			int _nDimH;
			int _nDimW;
			int _nDimD;
			Unit _dimU;
			double _dPrice;
			std::string _strURI;
			std::string _strReference;
			std::string _strStatus;
			bool _bSlideShow;
			std::string _strUpdated;

			std::string _strUnit;
			std::string _strSetUnit;

		public:
			Article();
			Article( const Article& article );
			virtual ~Article();

			const Article& operator=( const Article& article );

			int articleId() const;
			const CADAData::Dealer& dealer() const throw( CADAData::Exception );
			const CADAData::Gallery& gallery() const throw( CADAData::Exception );
			const std::string& shortDesc() const;
			const std::string& description() const;
			const std::string& faults() const;
			const std::string& circa() const;
			const std::string& note() const;
			const std::string& image0() const;
			const std::string& image1() const;
			const std::string& imageS() const;
			int dimH() const;
			int dimW() const;
			int dimD() const;
			Unit dimU() const;
			double price() const;
			const std::string& uri() const;
			const std::string& reference() const;
			const std::string& status() const;
			bool slideShow() const;
			const std::string& updated() const;
			void setArticleId( int nArticleId );
			void setDealer( const CADAData::Dealer& dealer );
			void setGallery( const CADAData::Gallery& gallery );
			void setShortDesc( const std::string& strShortDesc );
			void setDescription( const std::string& strDescription );
			void setFaults( const std::string& strFaults );
			void setCirca( const std::string& strCirca );
			void setNote( const std::string& strNote );
			void setImage0( const std::string& strImage0 );
			void setImage1( const std::string& strImage1 );
			void setImageS( const std::string& strImageS );
			void setDimH( int nDimH );
			void setDimW( int nDimW );
			void setDimD( int nDimD );
			void setDimU( Unit dimU );
			void setPrice( double _dPrice );
			void setURI( const std::string& strURI );
			void setReference( const std::string& strReference );
			void setStatus( const std::string& strStatus );
			void setSlideShow( bool bSlideShow );

			void setUnit( const std::string& strUnit );
			void setSetUnit( const std::string& strUnit );

			static Article& create( const Article& article, RfcDal::DalDatabase& db );
			void save( RfcDal::DalDatabase& db );
//			void toXML( Rfc::XMLNode& nodeParent, Mode mode = modeFull ) const throw( CADAData::Exception );

			static Article fromRow( const RfcDal::DalDatabase::Row& row, RfcDal::DalDatabase& db ) throw( CADAData::Exception );
			static Article fromXML( const Rfc::XMLNode& node ) throw( CADAData::Exception );

			static const std::map<int, std::string>& units();
			static const char* quarters( double d, Unit unitDisplay );
			static std::string formatDimensions( double dHeight, double dWidth, double dDepth, Unit unitStore, Unit unitDisplay );
	};

	class CADAData_Export ArticleMap : public std::map<int, Article>
	{
		public:
			ArticleMap();
			ArticleMap( const ArticleMap& articleS );
			virtual ~ArticleMap();

			const ArticleMap& operator=( const ArticleMap& articleS );

//			void toXML( Rfc::XMLNode& nodeParent, Mode mode = modeFull ) const;

			static ArticleMap fromResult( const RfcDal::DalDatabase::Result& result, RfcDal::DalDatabase& db ) throw( CADAData::Exception );
//			static ArticleMap fromXML( const Rfc::XMLNode& node ) throw( CADAData::Exception );
	};
};

#endif /* !__Article_h__ */
