#ifndef __cadadata_CADAFactory_h__
#define __cadadata_CADAFactory_h__

#include <cadadata/CADAData.h>

#include <cadadata/Exception.h>

#include <cadadata/Region.h>
#include <cadadata/ContactType.h>
#include <cadadata/Dealer.h>
#include <cadadata/Gallery.h>
#include <cadadata/GalleryRoot.h>
#include <cadadata/Article.h>
#include <cadadata/Txn.h>
#include <cadadata/CADAManager.h>

#include <Base4c/Version.h>

namespace CADAData
{
	class ArticleStatusMap : public std::map<std::string, std::string>
	{
	};

	class CADAData_Export CADAFactory
	{
		private:
			static CADAData::RegionMap _regionS;
			static CADAData::ContactTypeMap _contactTypeS;
			static CADAData::DealerMap _dealerS;
			static CADAData::GalleryMap _galleryS;
			static CADAData::GalleryRootMap _galleryRootS;
			static CADAData::ArticleMap _articleS;
			static CADAData::ArticleStatusMap _articleStatusS;
			static CADAData::TxnMap _txnS;

		public:
			static Base4c::Version version();
			static void initialize( const std::string& strInit ) throw( CADAData::Exception );

			static CADAData::RegionMap& regions();
			static CADAData::ContactTypeMap& contactTypes();
			static CADAData::DealerMap& dealers();
			static CADAData::GalleryMap& gallerys();
			static CADAData::GalleryRootMap& rootGallerys();
			static CADAData::ArticleMap& articles();
			static CADAData::ArticleMap& refreshArticles() throw( CADAData::Exception );
			static CADAData::ArticleStatusMap& articleStatuss();
			static CADAData::TxnMap& txns();

			static void createBulkTransactions( const std::string& strDescription, double dAmtRq ) throw( CADAData::Exception );

		private:
			static CADAManager* _pmanager;

		public:
			static void registerManager( CADAManager& manager );
			static void unregisterManager();
			static CADAManager& manager() throw( CADAData::Exception );

			static void openArticle( int nArticleId ) throw( CADAData::Exception );
			static void openArticle( Article& article ) throw( CADAData::Exception );
			static void createArticle() throw( CADAData::Exception );
			static void createArticle( int nArticleId ) throw( CADAData::Exception );
			static void openDealer( const std::string strDealer ) throw( CADAData::Exception );
			static void openDealer( Dealer& dealer ) throw( CADAData::Exception );
	};
}

#endif /* !__cadadata_CADAFactory_h__ */
