#ifndef __Calendar_h__
#define __Calendar_h__

#include <cadadata/CADAData.h>
#include <cadadata/Exception.h>

#include <librfcdal/DalDatabase.h>
//#include <librfc/XMLNode.hpp>

#include <string>
#include <vector>

namespace CADAData
{
	const int nNotACalendarRow = 4001;
	const int nNotACalendarNode = 4002;

	class CADAData_Export Calendar
	{
		private:
			int _nEvent;
			std::string _strStartWhen;
			std::string _strEndWhen;
			std::string _strTitle;
			std::string _strDescription;
			std::string _strURI;
			std::string _strURILegend;

		public:
			Calendar();
			Calendar( const Calendar& calendar );
			virtual ~Calendar();

			const Calendar& operator=( const Calendar& calendar );

			int event() const;
			const std::string& startWhen() const;
			const std::string& endWhen() const;
			const std::string& title() const;
			const std::string& description() const;
			const std::string& uri() const;
			const std::string& uriLegend() const;
			void setEvent( int nEvent );
			void setStartWhen( const std::string strStartWhen );
			void setEndWhen( const std::string strEndWhen );
			void setTitle( const std::string strTitle );
			void setDescription( const std::string strDescription );
			void setURI( const std::string strURI );
			void setURILegend( const std::string strURILegend );

			void save( RfcDal::DalDatabase& db );
//			void toXML( Rfc::XMLNode& nodeParent, bool bFull = true ) const;
//			void toXHTML( Rfc::XMLNode& nodeParent, bool bFull = true ) const;

			static Calendar fromRow( const RfcDal::DalDatabase::Row& row, RfcDal::DalDatabase& db ) throw( Exception );
//			static Calendar fromXML( const Rfc::XMLNode& node ) throw( Exception );
	};

	class CADAData_Export CalendarList : public std::vector<Calendar>
	{
		public:
			CalendarList();
			CalendarList( const CalendarList& calendarS );
			virtual ~CalendarList();

			const CalendarList& operator=( const CalendarList& calendarS );

//			void toXML( Rfc::XMLNode& nodeParent, bool bFull = true ) const;
//			void toXHTML( Rfc::XMLNode& nodeParent, bool bFull = true ) const;

			static CalendarList fromResult( const RfcDal::DalDatabase::Result& result, RfcDal::DalDatabase& db ) throw( Exception );
// 			static CalendarList fromXML( const Rfc::XMLNode& node ) throw( Exception );
	};
};

#endif /* !__Calendar_h__ */
