#ifndef __Day_h__
#define __Day_h__

#include <cadadata/CADAData.h>
#include <cadadata/Exception.h>

#include <librfcdal/DalDatabase.h>
// #include <librfc/XMLNode.hpp>

#include <string>
#include <vector>

namespace CADAData
{
	const int nNotADayRow = 8001;
	const int nNotADayNode = 8002;
	const int nNotADay = 8003;

	class CADAData_Export Day
	{
		public:
			typedef enum { dayAll = '*', dayMon = '1', dayTue = '2', dayWed = '3', dayThu = '4', dayFri = '5', daySat = '6', daySun = '7', dayPH = 'P', dayOthr = 'X' } EDay;

		private:
			EDay _day;
			std::string _strLegendEn;
			std::string _strLegendFr;

		public:
			Day();
			Day( const Day& day );
			virtual ~Day();

			const Day& operator=( const Day& day );

			EDay day() const;
			const std::string& legendEn() const;
			const std::string& legendFr() const;
			void setDay( EDay day );
			void setLegendEn( const std::string strLegendEn );
			void setLegendFr( const std::string strLegendFr );

			void save( RfcDal::DalDatabase& db );
// 			void toXML( Rfc::XMLNode& nodeParent, bool bFull = true ) const;
// 			void toXHTML( Rfc::XMLNode& nodeParent, bool bFull = true ) const;

			static Day fromRow( const RfcDal::DalDatabase::Row& row, RfcDal::DalDatabase& db ) throw( Exception );
// 			static Day fromXML( const Rfc::XMLNode& node ) throw( Exception );
			static EDay fromText( const std::string& strDay );
			static std::string toText( EDay day );
	};

	class CADAData_Export DayList : public std::vector<Day>
	{
		public:
			DayList();
			DayList( const DayList& dayS );
			virtual ~DayList();

			const DayList& operator=( const DayList& dayS );

// 			void toXML( Rfc::XMLNode& nodeParent, bool bFull = true ) const;
// 			void toXHTML( Rfc::XMLNode& nodeParent, bool bFull = true ) const;

			static DayList fromResult( const RfcDal::DalDatabase::Result& result, RfcDal::DalDatabase& db ) throw( Exception );
// 			static DayList fromXML( const Rfc::XMLNode& node ) throw( Exception );
	};
};

#endif /* !__Day_h__ */
