#ifndef __Dealer_h__
#define __Dealer_h__

#include <cadadata/Base.h>
#include <cadadata/Exception.h>
#include <cadadata/Region.h>
#include <cadadata/DealerContact.h>
#include <cadadata/DealerHours.h>

#include <librfcdal/DalDatabase.h>
// #include <librfc/XMLNode.hpp>

#include <string>
#include <map>

namespace CADAData
{
//	const int nNotADealerRow = 1001;
//	const int nNotADealerNode = 1002;
//	const int nDealerCreateFailed = 1003;
//	const int nDealerUpdateFailed = 1004;
//	const int nDealerDeleteFailed = 1005;

	class TxnPtrMap;

	class CADAData_Export Dealer //: public Base
	{
		private:
			std::string _strDealer;
			bool _bIsActive;
			std::string _strTitle;
			std::string _strContact;
			const CADAData::Region* _pregion;
			std::string _strAddress;
			std::string _strDescription;
			std::string _strEmailPrivate;
			std::string _strIndexURI;
			std::string _strPrefixURI;
			std::string _strLegend;
			DealerContactMap _contactS;
			DealerHoursList _hourS;
			TxnPtrMap* _ptxnS;

		public:
			Dealer();
			Dealer( const Dealer& dealer );
			virtual ~Dealer();

			const Dealer& operator=( const Dealer& dealer );
			const Dealer& merge( const Dealer& dealer );

			const std::string& dealer() const;
			bool isActive() const;
			const std::string& title() const;
			const std::string& contact() const;
			const CADAData::Region& region() const throw( CADAData::Exception );
			const std::string& address() const;
			const std::string& description() const;
			const std::string& emailPrivate() const;
			const std::string& indexURI() const;
			const std::string& prefixURI() const;
			const std::string& legend() const;
			const DealerContactMap& contacts() const;
			const DealerHoursList& hours() const;
			const TxnPtrMap& txns() const;

			void setDealer( const std::string& strDealer );
			void setIsActive( bool bIsActive );
			void setTitle( const std::string& strTitle );
			void setContact( const std::string& strContact );
			void setRegion( const CADAData::Region& region );
			void setAddress( const std::string& strAddress );
			void setDescription( const std::string& strDescription );
			void setEmailPrivate( const std::string& strEmailPrivate );
			void setIndexURI( const std::string& strIndexURI );
			void setPrefixURI( const std::string& strPrefixURI );
			void setLegend( const std::string& strLegend );
			DealerContactMap& contacts();
			DealerHoursList& hours();
			TxnPtrMap& txns();

// 			virtual void toXML( Rfc::XMLNode& nodeParent, Mode mode = modeFull ) const throw( CADAData::Exception );

			static Dealer fromRow( const RfcDal::DalDatabase::Row& row, RfcDal::DalDatabase& db ) throw( CADAData::Exception );
			static Dealer& create( const Dealer& dealer, RfcDal::DalDatabase& db ) throw( CADAData::Exception );
			void update( RfcDal::DalDatabase& db ) throw( CADAData::Exception );
// 			static Dealer fromXML( const Rfc::XMLNode& node ) throw( CADAData::Exception );
	};

	class CADAData_Export DealerMap : /*public List,*/ public std::map<std::string, Dealer>
	{
		public:
			DealerMap();
			DealerMap( const DealerMap& dealerS );
			virtual ~DealerMap();

			const DealerMap& operator=( const DealerMap& dealerS );

// 			virtual void toXML( Rfc::XMLNode& nodeParent, Mode mode = modeFull ) const;

			static DealerMap fromResult( const RfcDal::DalDatabase::Result& result, RfcDal::DalDatabase& db ) throw( Exception );
// 			static DealerMap fromXML( const Rfc::XMLNode& node ) throw( Exception );
	};
}

#endif /* !__Dealer_h__ */
