#ifndef __DealerHours_h__
#define __DealerHours_h__

#include <cadadata/CADAData.h>
#include <cadadata/Exception.h>
#include <cadadata/Day.h>
#include <cadadata/Status.h>

#include <librfcdal/DalDatabase.h>
// #include <librfc/XMLNode.hpp>

#include <string>
#include <vector>

namespace CADAData
{
	const int nNotADealerHoursRow = 7001;
	const int nNotADealerHoursNode = 7002;

	class CADAData_Export DealerHours
	{
		private:
			std::string _strDealer;
			Day::EDay _day;
			Status::EStatus _status;
			std::string _strOpenTime;
			std::string _strCloseTime;

		public:
			DealerHours();
			DealerHours( const DealerHours& dealerHours );
			virtual ~DealerHours();

			const DealerHours& operator=( const DealerHours& dealerHours );

			const std::string& dealer() const;
			Day::EDay day() const;
			Status::EStatus status() const;
			const std::string& openTime() const;
			const std::string& closeTime() const;
			void setDealer( const std::string strDealer );
			void setDay( Day::EDay day );
			void setStatus( Status::EStatus status );
			void setOpenTime( const std::string strOpenTime );
			void setCloseTime( const std::string strCloseTime );

			void save( RfcDal::DalDatabase& db );
// 			void toXML( Rfc::XMLNode& nodeParent, bool bFull = true ) const;

			static DealerHours fromRow( const RfcDal::DalDatabase::Row& row, RfcDal::DalDatabase& db ) throw( Exception );
// 			static DealerHours fromXML( const Rfc::XMLNode& node ) throw( Exception );
	};

	class CADAData_Export DealerHoursList : public std::vector<DealerHours>
	{
		public:
			DealerHoursList();
			DealerHoursList( const DealerHoursList& dealerHoursS );
			virtual ~DealerHoursList();

			const DealerHoursList& operator=( const DealerHoursList& dealerHoursS );

// 			void toXML( Rfc::XMLNode& nodeParent, bool bFull = true ) const;

			static DealerHoursList fromResult( const RfcDal::DalDatabase::Result& result, RfcDal::DalDatabase& db ) throw( Exception );
// 			static DealerHoursList fromXML( const Rfc::XMLNode& node ) throw( Exception );
	};
};

#endif /* !__DealerHours_h__ */
