#ifndef __CADAData_Exception_h__
#define __CADAData_Exception_h__

#include <cadadata/CADAData.h>

#include <string>
#include <ostream>
#include <map>

namespace CADAData
{
	const int CDX_ALIENEXCEPTION = 101;
	const int CDX_NOCONNECTSTRING = 121;
	const int CDX_DALEXCEPTION = 111;
	const int CDX_DALERROR = 112;
	const int CDX_MALFORMEDXML = 121;
	const int CDX_MALFORMEDROW = 122;
	const int CDX_MANAGERNOTREGISTERED = 140;
	const int CDX_ARTICLEIDEXISTS = 201;
	const int CDX_NOSUCHDEALER = 301;
	const int CDX_NOSUCHUNIT = 302;
	const int CDX_NOSUCHGALLERY = 303;
	const int CDX_NOSUCHREGION = 304;
	const int CDX_NOSUCHCONTACTTYPE = 305;
	const int CDX_NOSUCHARTICLE = 306;
	const int CDX_NODEALERSET = 401;
	const int CDX_NOGALLERYSET = 403;
	const int CDX_NOREGIONSET = 404;
	const int CDX_NOCONTACTTYPESET = 405;
	const int CDX_FILEOPENFAILED = 500;

	class CADAData_Export Exception
	{
		private:
			std::string _strFile;
			int _nLine;
			int _nErrorCode;
			std::string _strException;
			static std::map<int, std::string> _strExplanationS;

		public:
			Exception( const std::string& strFile, int nLine, int nErrorCode, const std::string& strException = std::string() );
			virtual ~Exception();

			const std::string& file() const;
			int line() const;
			int errorCode() const;
			const std::string& exception() const;
			static const std::string& explainErrorCode( int nErrorCode );
	};
};

std::ostream& operator<<( std::ostream& os, const CADAData::Exception& e );

#endif /* !__CADAData_Exception_h__ */
