#ifndef __Status_h__
#define __Status_h__

#include <cadadata/CADAData.h>
#include <cadadata/Exception.h>

#include <librfcdal/DalDatabase.h>
// #include <librfc/XMLNode.hpp>

#include <string>
#include <vector>

namespace CADAData
{
	const int nNotAStatusRow = 9001;
	const int nNotAStatusNode = 9002;
	const int nNotAStatus = 9003;

	class CADAData_Export Status
	{
		public:
			typedef enum { statByAppt = 'A', statClosed = 'C', statOpen = 'O'  } EStatus;

		private:
			EStatus _status;
			std::string _strLegendEn;
			std::string _strLegendFr;

		public:
			Status();
			Status( const Status& status );
			virtual ~Status();

			const Status& operator=( const Status& status );

			EStatus status() const;
			const std::string& legendEn() const;
			const std::string& legendFr() const;
			void setStatus( EStatus status );
			void setLegendEn( const std::string strLegendEn );
			void setLegendFr( const std::string strLegendFr );

			void save( RfcDal::DalDatabase& db );
// 			void toXML( Rfc::XMLNode& nodeParent, bool bFull = true ) const;
// 			void toXHTML( Rfc::XMLNode& nodeParent, bool bFull = true ) const;

			static Status fromRow( const RfcDal::DalDatabase::Row& row, RfcDal::DalDatabase& db ) throw( Exception );
// 			static Status fromXML( const Rfc::XMLNode& node ) throw( Exception );
			static EStatus fromText( const std::string& strStatus );
			static std::string toText( EStatus status );
	};

	class CADAData_Export StatusList : public std::vector<Status>
	{
		public:
			StatusList();
			StatusList( const StatusList& statusS );
			virtual ~StatusList();

			const StatusList& operator=( const StatusList& statusS );

// 			void toXML( Rfc::XMLNode& nodeParent, bool bFull = true ) const;
// 			void toXHTML( Rfc::XMLNode& nodeParent, bool bFull = true ) const;

			static StatusList fromResult( const RfcDal::DalDatabase::Result& result, RfcDal::DalDatabase& db ) throw( Exception );
// 			static StatusList fromXML( const Rfc::XMLNode& node ) throw( Exception );
	};
};

#endif /* !__Status_h__ */
