#ifndef __Txn_h__
#define __Txn_h__

#include <cadadata/CADAData.h>

#include <cadadata/Exception.h>
#include <cadadata/Dealer.h>

#include <Base4c/Date.h>

#include <map>

namespace CADAData
{
	class CADAData_Export Txn
	{
		private:
			int _nTxn;
			Base4c::Date _dtIssued;
			std::string _strDealer;
			std::string _strDescription;
			double _dAmtRq;
			Base4c::Date _dtRcvd;
			double _dAmtRc;
			std::string _strQ;
			bool _bCancelled;

		public:
			Txn();
			Txn( int nTxn );
			Txn( const Txn& txn );
			virtual ~Txn();

			Txn& operator=( const Txn& txn );

			int txn() const;
			const Base4c::Date& issued() const;
			Dealer& dealer() throw( CADAData::Exception );
			const std::string& description();
			double amtRq() const;
			const Base4c::Date& rcvd() const;
			double amtRc() const;
			const std::string& q() const;
			bool cancelled() const;

			void setIssued( const Base4c::Date& dtIssued );
			void setDealer( const Dealer& dealer );
			void setDescription( const std::string& strDescription );
			void setAmtRq( double dAmtRq );
			void setRcvd( const Base4c::Date& dtRcvd );
			void setAmtRc( double dAmtRc );
			void setQ( const std::string& strQ );
			void setCancelled( bool bCancelled );

			static Txn& create( const Txn& txn, RfcDal::DalDatabase& db ) throw( CADAData::Exception );
			void save( RfcDal::DalDatabase& db ) throw( CADAData::Exception );

			static Txn fromRow( const RfcDal::DalDatabase::Row& row, RfcDal::DalDatabase& db ) throw( CADAData::Exception );

			static int nextTxn( RfcDal::DalDatabase& db ) throw( CADAData::Exception );
	};

	class CADAData_Export TxnMap : public std::map<int, Txn>
	{
		public:
			static TxnMap fromResult( const RfcDal::DalDatabase::Result& result, RfcDal::DalDatabase& db ) throw( Exception );
	};

	class CADAData_Export TxnPtrMap : public std::map<int, Txn*>
	{
		public:
			TxnPtrMap();
			TxnPtrMap( TxnMap& txnS );
			TxnPtrMap filter( const Dealer &dealer );
	};
}

#endif /* !__Txn_h__ */
